ListArena

Struct ListArena 

pub struct ListArena<T> { /* private fields */ }
Compact typed arena index and list storage utilities. A simple append-only store for variable-length typed child lists.

Implementations

Source

impl<T> ListArena<T>

pub const fn new() -> Self

Creates an empty list arena.

pub fn with_capacity(capacity: usize) -> Self

Creates an empty list arena with capacity for capacity items.

pub fn push(&mut self, item: T) -> Idx<T>

Appends one item and returns its typed index.

pub fn push_many<I>(&mut self, items: I) -> IdRange<T>
where I: IntoIterator<Item = T>,

Appends a variable-length list and returns the typed range for it.

pub fn as_slice(&self) -> &[T]

Returns all arena items as a slice.

pub fn as_mut_slice(&mut self) -> &mut [T]

Returns all arena items as a mutable slice.

pub fn get(&self, range: IdRange<T>) -> &[T]

Returns the slice covered by range.

pub fn get_mut(&mut self, range: IdRange<T>) -> &mut [T]

Returns the mutable slice covered by range.

pub fn len(&self) -> usize

Returns the number of items in the arena.

pub fn is_empty(&self) -> bool

Returns true when the arena is empty.

pub fn into_vec(self) -> Vec<T>

Consumes the arena and returns the packed items.

pub fn into_boxed_slice(self) -> Box<[T]>

Consumes the arena and returns the packed items as a boxed slice.